%simulation d'une antenne forme de deux patch circulaire fonctionnant  1.5 GHz

%calcul de la longueur d'onde dans le patch  1.5 GHz
c0 = 3e8;
f0 = 1.5e9;
epsr = 2.2; %constante dilectrique du substrat
lambda_0 = c0/(2*sqrt(epsr)*f0);

%dimensions gomtriques du patch
r_patch = 0.99*1.841*c0/(2*pi*f0*sqrt(epsr));
h_patch = 2e-3; %hauteur du patch = sparation entre le patch et le plan de masse
pos_exc = 0.36*r_patch; %position du point d'excitation par rapport au centre du patch
sep = 3*r_patch; %sparation centre  centre entre les deux patchs circulaires
%dimensions du plan de masse (forme rectangulaire)
L_gnd = 6*r_patch; 
W_gnd = 3*r_patch; 

%cration du modle de l'antenne
%plan de masse
GndPlane = antenna.Rectangle('Length',L_gnd,'Width',W_gnd);
% les deux patchs
RadElement1 = antenna.Circle('Radius',r_patch,'Center',[-sep/2 0]);
RadElement2 = antenna.Circle('Radius',r_patch,'Center',[sep/2 0]);
RadElement = RadElement1+RadElement2; %assemblage sur la mme couche
%cration du dilectrique composant le substrat
MonDielec = dielectric('Name','Mon_dielectrique','EpsilonR',epsr,'LossTangent',tan_d);

%gnration du modle de l'antenne
MyPatch = pcbStack;
MyPatch.Name = 'Deux Patchs circulaires';
MyPatch.BoardThickness = h_patch;
MyPatch.BoardShape = GndPlane; %les bords de l'antenne sont dfinis par les dimensions
        %du plan de masse
MyPatch.Layers = {RadElement,MonDielec,GndPlane}; %dfinition des diffrentes couches
        %du pcb, en commenant par la couche suprieure.
%ajout de deux excitations (sur chaque patch)
MyPatch.FeedLocations = [-sep/2+pos_exc 0 1 3;sep/2+pos_exc 0 1 3]; %[x y Couche_signal Couche_gnd]


%maillage et affichage du modle
figure(1);
show(MyPatch);

%dfinition des frquences de calcul
freq_calc = linspace(1.3e9,1.7e9,21);

%lancement des diffrents calculs et affichage
%impdance
figure(2);
impedance(MyPatch,freq_calc);

%diagramme de Smith
figure(3);
ParamS = sparameters(MyPatch,freq_calc);
Smith = smithplot(ParamS,'GridType','Z');

%affichage de la distribution du courant  la frquence f0
figure(4);
current(MyPatch,f0);

%affichage du diagramme de rayonnement (gain) en 3D
figure(5);
pattern(MyPatch,f0,'Type','gain');

%beamwidth en fonction de l'angle d'lvation (azimuth = 0)
figure(6);
beamwidth(MyPatch,f0,0,1:1:360);
